pub struct WorkspaceCache {
pub written_at_unix_ms: Option<u64>,
pub worktree_expanded: HashMap<String, bool>,
pub project_expanded: HashMap<String, bool>,
pub tree_selected: usize,
pub cursor_identity: Option<CursorIdentity>,
pub muted_terminals: HashSet<String>,
pub acknowledged_outcomes: HashMap<String, u64>,
pub integration_prompt_version: Option<String>,
/* private fields */
}Fields
written_at_unix_ms: Option<u64>worktree_expanded: HashMap<String, bool>project_expanded: HashMap<String, bool>tree_selected: usizecursor_identity: Option<CursorIdentity>muted_terminals: HashSet<String>Stable wsx terminal IDs muted in this local UI.
acknowledged_outcomes: HashMap<String, u64>Provider outcome revisions acknowledged by explicit interaction, keyed by terminal ID.
integration_prompt_version: Option<String>wsx version for which the user dismissed the integration setup prompt.
Implementations