pub struct GlobalConfig {
pub tabs: Vec<String>,
pub projects: Vec<ProjectEntry>,
pub exclude_worktree_paths: Vec<String>,
pub mobile_detach_key: Option<String>,
}Fields
tabs: Vec<String>projects: Vec<ProjectEntry>exclude_worktree_paths: Vec<String>Worktree paths containing any of these substrings are hidden. Defaults to [“.claude/worktrees”] to exclude Claude agent worktrees.
mobile_detach_key: Option<String>Extra no-prefix tmux key bound to detach-client when –mobile is set. Example: “C-q”. Unset by default (use prefix + d as normal).
Implementations
Sourceimpl GlobalConfig
impl GlobalConfig
pub fn config_path() -> Option<PathBuf>
Sourcepub fn load() -> Result<(Self, Option<String>)>
pub fn load() -> Result<(Self, Option<String>)>
Returns (config, warning). On TOML parse error, falls back to defaults
and sets warning so the caller can surface it in the TUI status bar.
pub fn save(&self) -> Result<()>
pub fn is_worktree_excluded(&self, path: &PathBuf) -> bool
Sourcepub fn ordered_tabs(&self) -> Vec<Option<&str>>
pub fn ordered_tabs(&self) -> Vec<Option<&str>>
Returns tab order as [None, Some(“work”), …]. None = default tab (always first).
pub fn tab_exists(&self, name: &str) -> bool
Sourcepub fn project_tab<'a>(&'a self, path: &Path) -> Option<&'a str>
pub fn project_tab<'a>(&'a self, path: &Path) -> Option<&'a str>
Returns the tab name for the project at path, or None if unassigned.
Sourcepub fn move_project_tab(&mut self, path: &PathBuf, tab: Option<String>)
pub fn move_project_tab(&mut self, path: &PathBuf, tab: Option<String>)
Set or clear the tab assignment for the project at path.
pub fn add_project(&mut self, name: String, path: PathBuf)
pub fn remove_project(&mut self, path: &PathBuf)
pub fn set_alias(&mut self, project_path: &PathBuf, branch: &str, alias: &str)