pub fn set_alias(
config: &mut GlobalConfig,
proj_path: &PathBuf,
branch: &str,
alias: &str,
)Expand description
Persist an alias for a branch in the global config. Caller must call config.save().
pub fn set_alias(
config: &mut GlobalConfig,
proj_path: &PathBuf,
branch: &str,
alias: &str,
)Persist an alias for a branch in the global config. Caller must call config.save().